using UnityEngine;
using System.Collections;

public class GameControlScript : MonoBehaviour {
	
	//We create an array of spawnpoints that will allow
	//us to randomnly place a powerup
	public Transform[] spawnPoints;
	public GameObject powerup;
	
	//Here we declare our game control variables
	private float timeLeft 				= 25F;	//time until game over
	private float timeAddedByPowerup 	= 1F;	//amount given by a powerup
	private float timeIncrement 		= 0.05F;//amount or values will increase
	private float spawnDelay 			= 1.0F;	//how often we spawn a powerup
	private int   powerupsCollected 	= 0;	//our score
	
	// Use this for initialization
	void Start () {
		//We should hide the cursor from the screen
		Screen.showCursor = false;
		SpawnPowerup();
	}
	
	// Update is called once per frame
	void Update () {
		//Here we slowly decrease the clock and check for a gameover
		//condition. When time runs out game is over
		timeLeft -= Time.deltaTime;
		if(timeLeft <= 0.0F)
		{
			print("game over");
		}
	}
	
	//Function SpawnPowerup will generate a powerup and then 'invoke'
	//itself. This will cause it to be called again automatically
	//after a set amount of time
	void SpawnPowerup()
	{
		//Here we get a random number and use that to selecte
		//a random spawn point
		int location = Random.Range(0, spawnPoints.Length);
		
		//then we generate a random offset so not all of the 
		//powerups spawn at the same point
		float xOffset = Random.Range(-1.5F, 1.5F);
		float zOffset = Random.Range(-1.5F, 1.5F);
		
		//we save the transform of the spawnpoint chosen
		Vector3 pos = spawnPoints[location].position;
		
		//we create a powerup at the spawnpoint using the offsets
		Instantiate(powerup, new Vector3(pos.x + xOffset, pos.y, pos.z + zOffset), Quaternion.identity);
		
		//we call this function again after the delay is up
		Invoke("SpawnPowerup", spawnDelay);
	}
	
	//PowerupsCollected will be called by the powerups when they
	//are triggered. The function increases the value of powerups, 
	//increases the delay, and adds time to the clock
	public void PowerupCollected()
	{
		//Add time to clock
		timeLeft += timeAddedByPowerup;
		//increase score
		powerupsCollected++;
		
		//increases delay and powerup value
		spawnDelay += timeIncrement;
		timeAddedByPowerup += (timeIncrement / 2);
	}

    void OnGUI()
    {
        //We output the score and the time remaining to the screen
        GUI.Label(new Rect(Screen.width / 2 - 10, Screen.height - 70, 90, 40), "Time Left: " + ((int)timeLeft));
        GUI.Label(new Rect(Screen.width / 2 - 10, Screen.height - 50, 90, 40), "Powerups Collected: " + powerupsCollected);
    }
}
